CMap

Struct CMap 

pub struct CMap { /* private fields */ }
A parsed cmap.

Implementations

Source

impl CMap

pub fn parse<'a>( data: &[u8], get_cmap: impl Fn(CMapName<'_>) -> Option<&'a [u8]> + Clone + 'a, ) -> Option<CMap>

Parse a cmap from raw bytes.

The get_cmap callback is used to recursively resolve cmaps that are referenced via usecmap.

pub fn identity_h() -> CMap

Create an Identity-H cmap.

pub fn identity_v() -> CMap

Create an Identity-V cmap.

pub fn metadata(&self) -> &Metadata

Return the metadata of this cmap.

pub fn lookup_cid_code(&self, code: u32, byte_len: u8) -> Option<u32>

Look up the CID code of a character code.

Returns None if the code does not match any range for the given byte length.

pub fn lookup_bf_string(&self, code: u32) -> Option<BfString>

Look up a bf string in the cmap. This is usually used for mapping character codes to Unicode codepoints in a ToUnicode cmap.

Returns None if no mapping is available.