pub struct StencilImage<'a, 'b> { /* private fields */ }Expand description
A stencil image.
Implementations
Sourceimpl<'a, 'b> StencilImage<'a, 'b>
impl<'a, 'b> StencilImage<'a, 'b>
Sourcepub fn with_stencil(
&self,
func: impl FnOnce(LumaData, &Paint<'a>),
target_dimension: Option<(u32, u32)>,
)
pub fn with_stencil( &self, func: impl FnOnce(LumaData, &Paint<'a>), target_dimension: Option<(u32, u32)>, )
Perform some operation with the stencil data of the image.
The second argument allows you to give the image decoder a hint for what resolution of the image you want to have. Note that this does not mean that the resulting image will have that dimension. Instead, it allows the image decoder to extract a lower-resolution version of the image in certain cases.