PageExt

Trait PageExt 

pub trait PageExt {
    // Required method
    fn initial_transform(&self, invert_y: bool) -> Affine;
}
Extension methods for PDF pages.

Required Methods

fn initial_transform(&self, invert_y: bool) -> Affine

Return the initial transform that should be applied when rendering. This accounts for a number of factors, such as the mismatch between PDF’s y-up and most renderers’ y-down coordinate system, the rotation of the page and the offset of the crop box.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PageExt for Page<'_>

Source

fn initial_transform(&self, invert_y: bool) -> Affine

Implementors