A parser for cmap files, as they are found in PDFs.
This crate provides a parser for cmap files and allows you to
- Map character codes from text-showing operators to CID identifiers.
- Map CIDs to Unicode characters or strings.
Safety
This crate forbids unsafe code via a crate-level attribute.
Structs
- CMap
- A parsed cmap.
- Character
Collection - A CID character collection identifying the character set and ordering.
- CidRange
- A range of character codes mapped to CIDs.
- Metadata
- Metadata extracted from a cmap file.
Enums
- BfString
- A Unicode value decoded from a cmap.
- CMap
Name - The name of the cmap.
- CidFamily
- The registry+ordering family of a CID character collection.
- Writing
Mode - The writing mode of a cmap.
Functions
- load_
embedded - Load the data for a cmap file, by name.
Type Aliases
- Cid
- A CID (Character Identifier).