OutlineGlyph

Struct OutlineGlyph 

pub struct OutlineGlyph { /* private fields */ }
A glyph defined by an outline.

Implementations

Source

impl OutlineGlyph

pub fn outline(&self) -> BezPath

Return the outline of the glyph, assuming an upem value of 1000.

pub fn identifier(&self) -> GlyphIdentifier

Return the identifier of the glyph. You can use this to calculate the cache key for the glyph.

Note that the glyph_transform attribute is not considered in the cache key of the identifier, only the glyph ID and the font.

pub fn as_unicode(&self) -> Option<BfString>

Returns the Unicode code point for this glyph, if available.

See Glyph::as_unicode for details on the fallback chain used.

pub fn font_data(&self) -> Option<OutlineFontData>

Get raw font bytes and metadata for downstream use.

Returns None for Type1 fonts.

pub fn glyph_id(&self) -> GlyphId

Get the glyph ID within the font.

pub fn advance_width(&self) -> Option<f32>

Get the advance width for this glyph.

The advance width is how far to move horizontally after drawing this glyph before drawing the next one.

pub fn font_cache_key(&self) -> u128

Get the cache key for this glyph’s font.

This identifies the font uniquely, even when font_data() returns None (e.g., for Type1 fonts). Useful for grouping glyphs by font.